@@ -6,7 +6,7 @@ from concurrent.futures import ThreadPoolExecutor
 
 import pandas as pd
 from rich.progress import Progress
-from rich.progress import track
+from tqdm import tqdm
 
 from .cas import CAS
 from .config import settings
@@ -50,17 +50,17 @@ class Collect:
     async def run_keys(self, keys):
         loop = asyncio.get_event_loop()
         executor = ThreadPoolExecutor(200)
+        pbar = tqdm(total=len(keys), desc=f"Getting keys in {settings.base}")
 
         await asyncio.gather(
             *[
                 loop.run_in_executor(
-                    executor, functools.partial(self.parallel_docs, doc, cdclass),
-                )
-                for cdclass, doc in track(
-                    keys, description=f"Getting keys in {settings.base}"
+                    executor, functools.partial(self.parallel_docs, doc, cdclass, pbar),
                 )
+                for cdclass, doc in keys
             ]
         )
+        pbar.close()
 
     def parallel_classes(self, progress, task, cdclass):
         loop = asyncio.new_event_loop()
@@ -80,8 +80,10 @@ class Collect:
         logger.info(f"Finished class {cdclass}")
         progress.advance(task)
 
-    def parallel_docs(self, doc, cdclass):
+    def parallel_docs(self, doc, cdclass, pbar=None):
         logger.info(f"Getting key {doc} in class {cdclass}")
+        if pbar:
+            pbar.update()
         if doc:
             self.get_objects(doc, cdclass)
         else:
