@@ -54,6 +54,12 @@ def validate_s3():
     validate(v)
 
 
+def validate_cas():
+    logger.info("Validating CAS variables")
+    v = [Validator("CAS", must_exist=True)]
+    validate(v)
+
+
 def validate(v):
     settings.validators.register(*v)
     settings.validators.validate()
