@@ -39,7 +39,7 @@ class Abstract_DB(ABC):
 
     def get_objects(self, key):
         sql = get_sql(settings.objs_sql).format(KEY=key)
-        objects = self.select(sql)
+        objects = list(self.select(sql))
         if len(objects) > 0:
             logger.info(f"Found {len(objects)} objects for key {key}")
         else:
